@@ -23,7 +23,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <glib.h>
-#include <gdk/gdkkeysyms.h>
 #include "debug.h"
 #include "buffer.h"
 #include "iso2022.h"
@@ -36,6 +35,15 @@
 #endif
 #include <glib/gi18n-lib.h>
 
+#include <gtk/gtk.h>
+
+#if GTK_CHECK_VERSION (2, 90, 7)
+#define GDK_KEY(symbol) GDK_KEY_##symbol
+#else
+#include <gdk/gdkkeysyms.h>
+#define GDK_KEY(symbol) GDK_##symbol
+#endif
+
 /* Maps which jive with XTerm's ESC ()*+ ? sequences, RFC 1468.  Add the
  * PC437 map because despite knowing that XTerm doesn't support it, certain
  * applications try to use it anyway. */
@@ -115,7 +123,7 @@ static const struct _vte_iso2022_map16 _vte_iso2022_map_0[] = {
 };
 /* United Kingdom.  VT100 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_A[] = {
-	{'$', GDK_sterling},
+	{'$', GDK_KEY (sterling)},
 };
 /* US-ASCII (no conversions).  VT100 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_B[] = {
@@ -123,128 +131,128 @@ static const struct _vte_iso2022_map16 _vte_iso2022_map_B[] = {
 };
 /* Dutch. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_4[] = {
-	{'#',  GDK_sterling},
-	{'@',  GDK_threequarters},
-	{'[',  GDK_ydiaeresis},
-	{'\\', GDK_onehalf},
-	{']',  GDK_bar}, /* FIXME? not in XTerm 170 */
-	{'{',  GDK_diaeresis},
+	{'#',  GDK_KEY (sterling)},
+	{'@',  GDK_KEY (threequarters)},
+	{'[',  GDK_KEY (ydiaeresis)},
+	{'\\', GDK_KEY (onehalf)},
+	{']',  GDK_KEY (bar)}, /* FIXME? not in XTerm 170 */
+	{'{',  GDK_KEY (diaeresis)},
 	{'|',  0x192}, /* f with hook (florin) */ /* FIXME? not in XTerm 170 */
-	{'}',  GDK_onequarter},
-	{'~',  GDK_acute}
+	{'}',  GDK_KEY (onequarter)},
+	{'~',  GDK_KEY (acute)}
 };
 /* Finnish. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_C[] = {
-	{'[',  GDK_Adiaeresis},
-	{'\\', GDK_Odiaeresis},
-	{']',  GDK_Aring},
-	{'^',  GDK_Udiaeresis},
-	{'`',  GDK_eacute},
-	{'{',  GDK_adiaeresis},
-	{'|',  GDK_odiaeresis},
-	{'}',  GDK_aring},
-	{'~',  GDK_udiaeresis},
+	{'[',  GDK_KEY (Adiaeresis)},
+	{'\\', GDK_KEY (Odiaeresis)},
+	{']',  GDK_KEY (Aring)},
+	{'^',  GDK_KEY (Udiaeresis)},
+	{'`',  GDK_KEY (eacute)},
+	{'{',  GDK_KEY (adiaeresis)},
+	{'|',  GDK_KEY (odiaeresis)},
+	{'}',  GDK_KEY (aring)},
+	{'~',  GDK_KEY (udiaeresis)},
 };
 /* French. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_R[] = {
-	{'#',  GDK_sterling},
-	{'@',  GDK_agrave},
-	{'[',  GDK_degree},
-	{'\\', GDK_ccedilla},
-	{']',  GDK_section},
-	{'{',  GDK_eacute},
-	{'|',  GDK_ugrave},
-	{'}',  GDK_egrave},
-	{'~',  GDK_diaeresis},
+	{'#',  GDK_KEY (sterling)},
+	{'@',  GDK_KEY (agrave)},
+	{'[',  GDK_KEY (degree)},
+	{'\\', GDK_KEY (ccedilla)},
+	{']',  GDK_KEY (section)},
+	{'{',  GDK_KEY (eacute)},
+	{'|',  GDK_KEY (ugrave)},
+	{'}',  GDK_KEY (egrave)},
+	{'~',  GDK_KEY (diaeresis)},
 };
 /* French Canadian. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_Q[] = {
-	{'@',  GDK_agrave},
-	{'[',  GDK_acircumflex},
-	{'\\', GDK_ccedilla},
-	{']',  GDK_ecircumflex},
-	{'^',  GDK_icircumflex},
-	{'`',  GDK_ocircumflex},
-	{'{',  GDK_eacute},
-	{'|',  GDK_ugrave},
-	{'}',  GDK_egrave},
-	{'~',  GDK_ucircumflex},
+	{'@',  GDK_KEY (agrave)},
+	{'[',  GDK_KEY (acircumflex)},
+	{'\\', GDK_KEY (ccedilla)},
+	{']',  GDK_KEY (ecircumflex)},
+	{'^',  GDK_KEY (icircumflex)},
+	{'`',  GDK_KEY (ocircumflex)},
+	{'{',  GDK_KEY (eacute)},
+	{'|',  GDK_KEY (ugrave)},
+	{'}',  GDK_KEY (egrave)},
+	{'~',  GDK_KEY (ucircumflex)},
 };
 /* German. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_K[] = {
-	{'@',  GDK_section},
-	{'[',  GDK_Adiaeresis},
-	{'\\', GDK_Odiaeresis},
-	{']',  GDK_Udiaeresis},
-	{'{',  GDK_adiaeresis},
-	{'|',  GDK_odiaeresis},
-	{'}',  GDK_udiaeresis},
-	{'~',  GDK_ssharp},
+	{'@',  GDK_KEY (section)},
+	{'[',  GDK_KEY (Adiaeresis)},
+	{'\\', GDK_KEY (Odiaeresis)},
+	{']',  GDK_KEY (Udiaeresis)},
+	{'{',  GDK_KEY (adiaeresis)},
+	{'|',  GDK_KEY (odiaeresis)},
+	{'}',  GDK_KEY (udiaeresis)},
+	{'~',  GDK_KEY (ssharp)},
 };
 /* Italian. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_Y[] = {
-	{'#',  GDK_sterling},
-	{'@',  GDK_section},
-	{'[',  GDK_degree},
-	{'\\', GDK_ccedilla},
-	{']',  GDK_eacute},
-	{'`',  GDK_ugrave},
-	{'{',  GDK_agrave},
-	{'|',  GDK_ograve},
-	{'}',  GDK_egrave},
-	{'~',  GDK_igrave},
+	{'#',  GDK_KEY (sterling)},
+	{'@',  GDK_KEY (section)},
+	{'[',  GDK_KEY (degree)},
+	{'\\', GDK_KEY (ccedilla)},
+	{']',  GDK_KEY (eacute)},
+	{'`',  GDK_KEY (ugrave)},
+	{'{',  GDK_KEY (agrave)},
+	{'|',  GDK_KEY (ograve)},
+	{'}',  GDK_KEY (egrave)},
+	{'~',  GDK_KEY (igrave)},
 };
 /* Norwegian and Danish. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_E[] = {
-	{'@',  GDK_Adiaeresis},
-	{'[',  GDK_AE},
-	{'\\', GDK_Ooblique},
-	{']',  GDK_Aring},
-	{'^',  GDK_Udiaeresis},
-	{'`',  GDK_adiaeresis},
-	{'{',  GDK_ae},
-	{'|',  GDK_oslash},
-	{'}',  GDK_aring},
-	{'~',  GDK_udiaeresis},
+	{'@',  GDK_KEY (Adiaeresis)},
+	{'[',  GDK_KEY (AE)},
+	{'\\', GDK_KEY (Ooblique)},
+	{']',  GDK_KEY (Aring)},
+	{'^',  GDK_KEY (Udiaeresis)},
+	{'`',  GDK_KEY (adiaeresis)},
+	{'{',  GDK_KEY (ae)},
+	{'|',  GDK_KEY (oslash)},
+	{'}',  GDK_KEY (aring)},
+	{'~',  GDK_KEY (udiaeresis)},
 };
 /* Spanish. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_Z[] = {
-	{'#',  GDK_sterling},
-	{'@',  GDK_section},
-	{'[',  GDK_exclamdown},
-	{'\\', GDK_Ntilde},
-	{']',  GDK_questiondown},
-	{'{',  GDK_degree},
-	{'|',  GDK_ntilde},
-	{'}',  GDK_ccedilla},
+	{'#',  GDK_KEY (sterling)},
+	{'@',  GDK_KEY (section)},
+	{'[',  GDK_KEY (exclamdown)},
+	{'\\', GDK_KEY (Ntilde)},
+	{']',  GDK_KEY (questiondown)},
+	{'{',  GDK_KEY (degree)},
+	{'|',  GDK_KEY (ntilde)},
+	{'}',  GDK_KEY (ccedilla)},
 };
 /* Swedish. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_H[] = {
-	{'@',  GDK_Eacute},
-	{'[',  GDK_Adiaeresis},
-	{'\\', GDK_Odiaeresis},
-	{']',  GDK_Aring},
-	{'^',  GDK_Udiaeresis},
-	{'`',  GDK_eacute},
-	{'{',  GDK_adiaeresis},
-	{'|',  GDK_odiaeresis},
-	{'}',  GDK_aring},
-	{'~',  GDK_udiaeresis},
+	{'@',  GDK_KEY (Eacute)},
+	{'[',  GDK_KEY (Adiaeresis)},
+	{'\\', GDK_KEY (Odiaeresis)},
+	{']',  GDK_KEY (Aring)},
+	{'^',  GDK_KEY (Udiaeresis)},
+	{'`',  GDK_KEY (eacute)},
+	{'{',  GDK_KEY (adiaeresis)},
+	{'|',  GDK_KEY (odiaeresis)},
+	{'}',  GDK_KEY (aring)},
+	{'~',  GDK_KEY (udiaeresis)},
 };
 /* Swiss. VT220 and higher (per XTerm docs). */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_equal[] = {
-	{'#',  GDK_ugrave},
-	{'@',  GDK_agrave},
-	{'[',  GDK_eacute},
-	{'\\', GDK_ccedilla},
-	{']',  GDK_ecircumflex},
-	{'^',  GDK_icircumflex},
-	{'_',  GDK_egrave},
-	{'`',  GDK_ocircumflex},
-	{'{',  GDK_adiaeresis},
-	{'|',  GDK_odiaeresis},
-	{'}',  GDK_udiaeresis},
-	{'~',  GDK_ucircumflex},
+	{'#',  GDK_KEY (ugrave)},
+	{'@',  GDK_KEY (agrave)},
+	{'[',  GDK_KEY (eacute)},
+	{'\\', GDK_KEY (ccedilla)},
+	{']',  GDK_KEY (ecircumflex)},
+	{'^',  GDK_KEY (icircumflex)},
+	{'_',  GDK_KEY (egrave)},
+	{'`',  GDK_KEY (ocircumflex)},
+	{'{',  GDK_KEY (adiaeresis)},
+	{'|',  GDK_KEY (odiaeresis)},
+	{'}',  GDK_KEY (udiaeresis)},
+	{'~',  GDK_KEY (ucircumflex)},
 };
 /* Codepage 437. */
 static const struct _vte_iso2022_map16 _vte_iso2022_map_U[] = {
